/* Upgrade script from schema 6 to 11.01*/

/* Offers tables */
--   Replace the existing offers table with the new one.
--   Data will automatically be filled in from the offers API when we start.
DROP TABLE offers;
CREATE TABLE offers (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'offerid' INTEGER UNIQUE NOT NULL,
    'imageUrl' TEXT,
    'value' INTEGER NOT NULL DEFAULT 0,
    'type' INTEGER NOT NULL,
    'brand' TEXT,
    'summary' TEXT,
    'l1text' TEXT,
    'l2text' TEXT,
    'l3text' TEXT,
    'categoryid' INTEGER NOT NULL,
    'categorydesc' TEXT,
    'expirationdate' REAL,
    'activedate' REAL,
    'slot' INTEGER NOT NULL,
    'pSpt' INTEGER NOT NULL DEFAULT 0,
    'canHasADI' INTEGER NOT NULL DEFAULT 0,
    'cpn_state' INTEGER NOT NULL DEFAULT 0,
    'sc_state' INTEGER NOT NULL DEFAULT 0
);

/* Aisle tables*/
--   Denormalize the categoryid from aislenames to aisledetail.
--   Add a new column to the the aisledetail table.  Instead of just ADD-ing the column, we 
--   recreate the table, for performance reasons.
--   This script also handles data migration.
CREATE TABLE aisledetail_backup (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'storeid' INTEGER NOT NULL,
    'aislenameid' INTEGER NOT NULL,
    'sequence' INTEGER NOT NULL,
    'uuid' TEXT UNIQUE,
    'modtime' INTEGER NOT NULL
);
INSERT INTO aisledetail_backup SELECT id, storeid, aislenameid, sequence, uuid, modtime FROM aisledetail;
DROP INDEX aisledetail_storeid_idx;
DROP TABLE aisledetail;
CREATE TABLE aisledetail (
    'id' INTEGER PRIMARY KEY AUTOINCREMENT,
    'storeid' INTEGER NOT NULL,
    'aislenameid' INTEGER NOT NULL,
    'sequence' INTEGER NOT NULL,
    'uuid' TEXT UNIQUE,
    'modtime' INTEGER NOT NULL,
    'categoryid' INTEGER
);
CREATE INDEX aisledetail_storeid_idx
    ON aisledetail (storeid);
CREATE INDEX aisledetail_store_cat_idx
    ON aisledetail (storeid, categoryid);
INSERT INTO aisledetail SELECT d.id, d.storeid, d.aislenameid, d.sequence, d.uuid, d.modtime, n.categoryid FROM aisledetail_backup d inner join aislenames n on n.id = d.aislenameid;
DROP TABLE aisledetail_backup;
